@@ -35,7 +35,6 @@ from . import messages
 from . import object_properties
 from . import settings
 from . import settings_manager
-from . import sound
 from . import text_attribute_names
 from . import acss
 
@@ -98,23 +97,6 @@ class SpeechGenerator(generator.Generator):
         """
         generator.Generator._addGlobals(self, globalsDict)
         globalsDict['voice'] = self.voice
-        globalsDict['play'] = self.play
-
-    def play(self, key):
-        """Returns an array containing a sound.Sound instance.
-        The key can a value to be used to look up a filename in the
-        settings.py:sounds dictionary (e.g., a pyatspi.ROLE_* value)
-        or just the name of an audio file to use.
-        """
-        sounds = _settingsManager.getSetting('sounds')
-        try:
-            soundBite = sound.Sound(sounds[key])
-        except:
-            if isinstance(key, str):
-                soundBite = sound.Sound(key)
-            else:
-                soundBite = None
-        return [soundBite]
 
     def generateSpeech(self, obj, **args):
         return self.generate(obj, **args)
@@ -1671,6 +1653,10 @@ class SpeechGenerator(generator.Generator):
                    or args.get('forceList', False)):
             return []
 
+        if obj.getRole() == pyatspi.ROLE_MENU \
+           and obj.parent == self._script.utilities.topLevelObject(obj):
+            return []
+
         result = []
         acss = self.voice(SYSTEM)
         position, total = self._script.utilities.getPositionAndSetSize(obj)
